#!/bin/sh

#	paraminf_TO_csv.sh
# Programm liest aus einem Pro/E-WF2 Parameter-Export die 'Lokale Parameter'
# und wandelt ihn in eine CSV-Datei zur weiteren Verarbeitung z.B. in Excel o..
#
# Voraussetzungen:
# Benoetigt Erweiterungen der (globalen) %PATH% mit (z.B.):
# C:\Programme\UTfW	(UNIX-Tools-for-Windows) http://unxutils.sourceforge.net/ > UnxUtils.zip + UnxUpdates.zip
#
# Export erzeugen mit:
#	"Pro/E > Tools > Parameter... > Datei > Exportieren (Info)... > <modell_name>_par.txt
#	"Pro/E > Tools > Ausweisen... > Datei > Exportieren (Info)... > param.inf
#
#	Aufruf:
# sh <diese Datei> [[Laufwerk:]Pfad\]<modell_name>_par.txt
# sh <diese Datei> [[Laufwerk:]Pfad\]param.inf


#	History:
# 2006-05-04	F0117375	:Basisversion



##	Variablen setzen

PROCVER="2006-05-04"  # Programm Version YYYY-mm-dd

PROCDISC=ProEparaminf_TO_csv
AUTHOR="F0117375 ist CAD.de Mitglied\t\t(Manfred.Witte@gmx.de)"
UTfW=C:/Programme/UTfW
U_DATE=$UTfW/date
COUNT=0
SEP="|"
TMP1=$TMP/$PROCDISC.$$.1
TMP2=$TMP/$PROCDISC.$$.2
TMP3=$TMP/$PROCDISC.$$.3

##	Programm
START=$($U_DATE +%Y%m%d.%H%M%S)
if [ -z "$1" ] ; then
  echo -e "usage: $0 [[Laufwerk:]Pfad\]<modell_name>_par.txt"
  exit 1
fi
INDAT=$(echo -e "$1" | sed -e 's/\\/\//g')
INDIR=$(dirname $INDAT)
INFILE=$(basename "$INDAT")
OUTFILE=$INFILE.$START.csv
chdir $INDIR

# Datei von ueberfluessigem befreien (NUR 'Lokale Parameter')
CUTTAIL=$(grep -n "Parameter fr alternative Massenwerte" $INFILE | cut -d: -f1)
CUTTAIL=$(($CUTTAIL-1))
head -$CUTTAIL $INFILE | tail +6 > $TMP1

# KopfZeile der CSV-Datei vorbereiten
echo -e "ParameterName${SEP}Einheit${SEP}Beschreibung${SEP}Typ${SEP}Quelle${SEP}Zugriff${SEP}Ausgewiesen${SEP}Wert" > $OUTFILE

# ParameterBlock abschneiden, zerpfluecken, ausgeben
#while [ $(cat $TMP1 | wc -l) > 2 ] ; do
while [ -s $TMP1 ] ; do
  BLOCKEND=$(grep -n "^$" $TMP1 | head -1 | cut -d: -f1)
  head -$(($BLOCKEND-1)) $TMP1 > $TMP2
  tail +$(($BLOCKEND+1)) $TMP1 > $TMP3
  cat $TMP3 > $TMP1
  ParameterName=$(grep "TYP: " $TMP2 | cut -c 1-31 | sed -e 's/^ *//g;s/ *$//g')
  Wert=$(grep "TYP: " $TMP2 | cut -c 33-52 | sed -e 's/^ *//g;s/ *$//g')
  Einheit=$(grep "EINHEIT: " $TMP2 | cut -d: -f2 | sed -e 's/^ *//g;s/ *$//g')
  Typ=$(grep "TYP: " $TMP2 | cut -d: -f2 | sed -e 's/^ *//g;s/ *$//g')
  Quelle=$(grep "QUELLE: " $TMP2 | cut -d: -f2 | sed -e 's/^ *//g;s/ *$//g')
  Zugriff=$(grep "ZUGRIFF: " $TMP2 | cut -d: -f2 | sed -e 's/^ *//g;s/ *$//g')
  Ausgewiesen=$(grep "AUSGEWIESEN: " $TMP2 | cut -d: -f2 | sed -e 's/^ *//g;s/ *$//g')
  Beschreibung1=$(grep "BESCHREIBUNG: " $TMP2 | cut -d: -f2 | sed -e 's/^ *//g;s/ *$//g')
  Beschreibung2=$(cat $TMP2 | grep -v "TYP: " | grep -v "QUELLE: " | grep -v "ZUGRIFF: " |\
  	grep -v "AUSGEWIESEN: " | grep -v "BESCHREIBUNG: " | grep -v "EINHEIT: " |\
  	sed -e 's/                                                     //g;s/ *$//g' |\
  	tr -d '\n\f' )
if [ "$Typ" = "Reelle Zahl" ] ; then		# Exponential -> Dezimal
  Wert=$(echo $Wert | gawk '{printf("%1.9f\n",$0)}' | sed -e 's/0*$/0/g')
  Wert=$(echo $Wert |  sed -e 's/\./,/g')	# Dezimaltrenner
fi
  echo -e "$ParameterName${SEP}$Einheit${SEP}$Beschreibung1$Beschreibung2${SEP}$Typ${SEP}$Quelle${SEP}$Zugriff${SEP}$Ausgewiesen${SEP}$Wert" >> $OUTFILE
  echo -e ".\c"
  COUNT=$(($COUNT+1))
done

echo -e "\n\t# DONE #\t$COUNT ParameterBloecke ausgelesen
\t\t\tSTART: $START
\t\t\tENDE : $($U_DATE +%Y%m%d.%H%M%S)
\tExportDatei: $INDIR/$OUTFILE
\tTHX to $AUTHOR" | sed -e 's/\//\\/g'
rm $TMP1 $TMP2 $TMP3 >NUL 2>&1